/**
 * Funktion för att kopiera förväntningar till klippboken.
 *
 * Eftersom de förväntningar som står för kontrollerna i manualen oftast går att
 * använda på anmärkningsbladet i granskningsprotokollen kan denna funktion
 * spara både musrörelser och tid.
 *
 * Skriptet lägger till en knapp i varje DD-element med klassen `expect`.
 * Knappen är bara synlig när den har fokus eller när muspekaren befinner sig
 * över DD-elementet.
 */
((doc, nav) => {
    "use strict";

    /**
     * Knapp för att kopiera textinnehåll till klippboken.
     */
    class CopyButton {

        /**
         * Konstruera en knappinstans.
         *
         * @param parent DD-element som ska innahålla knappen.
         */
        constructor (parent) {
            const button     = parent.appendChild(doc.createElement("button"));
            button.className = "copy";
            button.type      = "button";

            button.appendChild(doc.createTextNode("Kopiera"));

            button.addEventListener("click", () => {
                const content = parent.textContent.trim().replace(/\s+/g, " ")
                .replace(/Kopiera$/, "");
                nav.clipboard.writeText(content);
            });
        }

    }


    /*
     * Initiering.
     */

    // Kontrollera kompatibilitet.
    if ("undefined" === typeof doc.querySelectorAll) {
        return;
    }

    doc.querySelectorAll(".expect dd").forEach((dd) => {
        new CopyButton(dd);
    });
})(document, navigator);
